<?php
/**
 * Stupid Deal Grep
 * 
 * Searches the stupid deal of the day for passed deals and sends an email if found.
 *
 * @author Eric Lamb <eric@ericlamb.net>
 * @version .01
 * @link http://blog.ericlamb.net/
 * @copyright 2008 Eric Lamb
 * @package    StupidGrep
 * @filesource
 * @example C:\ProjectFiles\php_cli>php check_for_guitars.php --search="guitar,method" --email="eric@ericlamb.net"
 */

/**
 * Include init script
 */
include 'inc.php';

/**
 * Include snoopy library
 */
include 'includes/classes/snoopy/Snoopy.class.php';

/**
 * Include e-mail library
 */
include 'includes/classes/mailer.class.php';

/**
 * URI to the Stupid Deal page
 * @global string	$uri_to_check 
 */
$uri_to_check = 'http://www.musiciansfriend.com/stupid';

/**
 * Template for email message
 * @global string	$uri_to_check 
 */
$htmlmessage = <<<HTML
Match found for <a href="$uri_to_check">%%search%%</a><br>
Title: %%title%% <br>
Sale Price: %%sale_price%%<br>
Original Price: %%og_price%%<br>
HTML;

/**
 * Flag to set search validation 
 * @global bool	$validate_search 
 */
$validate_search = FALSE;
if(!array_key_exists('search',$input)){
	$validate_search = TRUE;
} else {
	if(strlen($input['search']) <= 2){
		$validate_search = TRUE;
	}
}

if($validate_search){
	echo "Please enter what to search for:\n"; 
	while(1){
		
		$input['search'] = trim(fgets(STDIN)); // reads one line from STDIN
		if(strlen($input['search']) <= 2){//it's a valid string
			break;
		}
		echo "Please enter a something to search for ";
		echo "(at least 2 characters:\n";
		echo "Example: \"guitar,bass,dvd\"\n";
	}
}

/**
 * Flag to set email validation 
 * @global bool	$validate_email 
 */
$validate_email = FALSE;
if(!array_key_exists('email',$input)){
	$validate_email = TRUE;
} else {
	if(!checkEmail_basic($input['email'])){
		$validate_email = TRUE;
	}
}

if($validate_email){
	echo "Please enter an email to send the alert to:\n"; 
	while(1){
		
		$input['email'] = trim(fgets(STDIN)); // reads one line from STDIN
		if(checkEmail_basic($input['email'])){//it's a valid email
			break;
		}
		echo "Please enter a valid email address:\n";
	}
}


//grab the webpage
$snoopy = new Snoopy;
$snoopy->agent = "Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0)";
$snoopy->referer = "http://www.yahoo.com/";
$snoopy->fetch($uri_to_check);
if($results = $snoopy->results){

	//for now the page title is the only use of the <h1> tag so this is easy :)
	$pattern = "'<[^>]*h1[^>]*>(.*?)<[^>]*/h1[^>]*>'";
	preg_match($pattern, $results, $match);
	$page_title = $match['1'];

	//$page_title = $page_title['0'];

	$input['search'] = explode(',',$input['search']);

	//check if there's a match in the passed $input['search'] array
	$total = count($input['search']);
	$match_for = array();
	for($i=0;$i<$total;$i++){
		if(stristr($page_title, trim($input['search'][$i])) !== FALSE) {
			$match_for[] = trim($input['search'][$i]);
		} 
	}

	//send email if successful
	$total = count($match_for);
	if($total >= 1){

		//check if the search was done today...
		$sql = "SELECT * FROM mf_checks WHERE title = '".$DB->es($page_title)."' AND DATE_FORMAT(`date_checked`,'%m') = '".date('m')."' AND DATE_FORMAT(`date_checked`,'%d') = '".date('d')."' AND DATE_FORMAT(`date_checked`,'%Y') = '".date('Y')."' LIMIT 1";
		$DB->query($sql);
		if($DB->getNumRows() == '1'){ //alert has already been sent so break out...
			echo "Already sent today... exiting...";
			exit;
		}

		//match was found so get the price now
		$price_arr = explode('<div style="font-size:3em;color:#FF0000;font-weight:normal;padding:20px 0;">',$results);
		$price_arr = explode("\n",$price_arr['1']);
		$sale_price = strip_tags($price_arr['0']);
		$og_price = str_replace('Reg ','',strip_tags($price_arr['1']));

		$htmlmessage = str_replace(array('%%search%%','%%title%%','%%sale_price%%','%%og_price%%'),array('"'.implode(', ',$match_for).'"',$page_title,$sale_price,$og_price),$htmlmessage);
		
		$mail = new Mailer();
		$mail->From = $input['email'];
		$mail->FromName = $input['email'];
		$mail->Subject = 'Found: '.$page_title;
		$mail->AltBody = strip_tags($htmlmessage);
		$mail->MsgHTML($htmlmessage);
		$mail->AddAddress($input['email']);
		if($mail->Send()){
			echo "Mail Sent";
		} else {
			echo "Mail Not Sent";
		}

		//add to the db 
		$sql = "INSERT INTO mf_checks SET term = '".$DB->es(implode(', ',$match_for))."', title = '".$DB->es($page_title)."', sale_price = '".$DB->es($sale_price)."', og_price = '".$DB->es($og_price)."', date_checked = now(), alert_sent = '1'";
		$DB->query($sql);
	}

}
?>