<?php
/**
 * Program Initilization and base functions
 * 
 * This is the initilization script.
 *
 * @author Eric Lamb <eric@ericlamb.net>
 * @version .01
 * @link http://blog.ericlamb.net/
 * @copyright 2008 Eric Lamb
 * @package    StupidGrep
 * @filesource
 */

/**
 * All passed paramaters
 * @global array	$input 
 */
$input = arguments($argv);

/**
 * Include DB class
 */
include 'includes/classes/mySQL.class.php';

/**
 * Include DB connection values
 */
include 'includes/connect.php';

/**
 * Check if we're dealing with 0 paramaters or help
 */
if(isset($argv[1]) && in_array($argv[1], array('--help', '-h', '-?'))) {
	display_help();
	exit;
}

/**
 * Displays the CLI help mode.
 *
 * @param   string	$parse	The source directory to parse
 * @return  bool
 */
function display_help(){
	global $argv;
?>
Takes a given string (--search) and searches the 
Stupid Deal of the Day for a match. If a match is 
found an email is sent to (--email)

 Usage: 
 <?php echo $argv[0]; ?> <option>

 <option> With the --help, -help, -h,
 or -? options, you can get this help.

 Example:
 <?php echo $argv[0]; ?> --search="term1" --email="foo@bar.com"
<?
}

/**
 * Returns the passed array and createds the paramater array
 *
 * @param   array	$argv	Passed values
 * @return  array
 */
function arguments($argv) {
   $_ARG = array();
   foreach ($argv as $arg) {
       if (preg_match('#^-{1,2}([a-zA-Z0-9]*)=?(.*)$#', $arg, $matches)) {
           $key = $matches[1];
           switch ($matches[2]) {
               case '':
               case 'true':
               $arg = true;
               break;
               case 'false':
               $arg = false;
               break;
               default:
               $arg = $matches[2];
           }
           
           /* make unix like -afd == -a -f -d */            
           if(preg_match("/^-([a-zA-Z0-9]+)/", $matches[0], $match)) {
               $string = $match[1];
               for($i=0; strlen($string) > $i; $i++) {
                $_ARG[$string[$i]] = true;
               }
           } else {
               $_ARG[$key] = $arg; 
           }            
       } else {
           $_ARG['input'][] = $arg;
       }        
   }
   return $_ARG; 
}

/**
 * Validates an string to ensure it matches a valid email address syntax
 *
 * @param   string	$email	
 * @return  array
 */
function  checkEmail_basic($email) {
	if (!preg_match("/^([a-zA-Z0-9])+([a-zA-Z0-9\._-])*@([a-zA-Z0-9_-])+([a-zA-Z0-9\._-]+)+$/" , $email)) {	
		return false;
	}
	return true;
}
?>